@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: xml-types
 version: 0.3.6
-id: xml-types-0.3.6-0a5622d83032677699f095224f223b42
-key: xmlty_151QYEhtx8K8fdljg93q7Q
+id: xml-types-0.3.6-c95586b34c41769092e7d9cdd505a61e
+key: xmlty_7EgICK2A845GVcomKmGp2V
 license: MIT
 maintainer: jmillikin@gmail.com
 stability: experimental
@@ -18,11 +18,11 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/xml-types-0.3.6
 library-dirs: /usr/lib/ghc-7.10.3/site-local/xml-types-0.3.6
 data-dir: /usr/share/arm-linux-ghc-7.10.3/xml-types-0.3.6
-hs-libraries: HSxml-types-0.3.6-151QYEhtx8K8fdljg93q7Q
+hs-libraries: HSxml-types-0.3.6-7EgICK2A845GVcomKmGp2V
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
-    text-1.2.1.3-6c3c87c392cdf2c29fca1c10bbf7250b
+    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
 haddock-interfaces: /usr/share/doc/haskell-xml-types/html/xml-types.haddock
 haddock-html: /usr/share/doc/haskell-xml-types/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
